import{d as o,b as c,c as d,q as a}from"./registerWidgets.60bba559.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="51e66f55-5e7b-400b-8ebd-9deb541ce5ca",e._sentryDebugIdIdentifier="sentry-dbid-51e66f55-5e7b-400b-8ebd-9deb541ce5ca")}catch{}})();const _=["href"],r=o({__name:"DocsButton",props:{path:null},setup(e){return(t,n)=>{var s;return c(),d("a",{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"}," Docs ",8,_)}}});const b=a(r,[["__scopeId","data-v-9fec5678"]]);export{b as D};
//# sourceMappingURL=DocsButton.3dc38f60.js.map
