[data-v-60b2affa]:root{--main-font-family: DM Sans, sans-serif}[data-v-60b2affa]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-60b2affa]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-60b2affa]{background-color:#fff;padding:10px}.tab-menu[data-v-60b2affa]{display:flex;flex-direction:column;align-items:stretch;height:100%}.tab-menu .tabs[data-v-60b2affa]{display:flex;height:42px;background-color:#fff;padding:0 20px;border-bottom:1px solid transparent;justify-content:space-between}.tab-menu .tabs .group[data-v-60b2affa]{display:flex;align-items:center}.tab-menu .tabs .form-tab[data-v-60b2affa]{display:flex;gap:6px;color:#414a58;border:none;padding:16px 20px;font-size:14px;line-height:10px;align-items:center;justify-content:center;background-color:#fff;cursor:pointer;font-weight:500;transition:all .2s ease-in-out;border-bottom:1px solid transparent;font-family:DM Sans,sans-serif}.tab-menu .tabs .form-tab[data-v-60b2affa]:hover{background-color:#fff;color:#000}.tab-menu .tabs .form-tab.active[data-v-60b2affa]{color:#272d35;background-color:#fff;border-bottom:2px solid #3d79d8;font-weight:700}.tab-menu .content[data-v-60b2affa]{flex-grow:1;position:relative}.tab[data-v-9c2e92c2]{top:0;bottom:0;left:0;right:0;display:flex;flex-direction:column;height:100%;overflow:auto;position:absolute}
