import{v as s}from"./icons.86798a2e.js";import{d as r,a as c,b as i,c as d,e as _,z as l,U as u,q as f}from"./registerWidgets.60bba559.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7ee3722e-5ea4-49ae-a073-8123bb0ab3f9",e._sentryDebugIdIdentifier="sentry-dbid-7ee3722e-5ea4-49ae-a073-8123bb0ab3f9")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(a,n)=>{const o=c("icon");return i(),d("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(o,{class:"icon",path:l(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),u(" Editor ")])}}});const v=f(b,[["__scopeId","data-v-eaeb3a6e"]]);export{v as B};
//# sourceMappingURL=BackButton.dc0ff5f7.js.map
