.home[data-v-8c8bc27e]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100vh;width:100vw}.router[data-v-8c8bc27e]{height:100%;width:100%}.form[data-v-8c8bc27e]{height:100%;width:100%;border:none;border-radius:5px}
