import{_ as k}from"./logo.084e5d7c.js";import{q as i,b as s,c as o,O as u,Q as p,x as t,d as f,H as I,a as x,z as _,N as b,e as r,w as g,U as m,F as $,L as w,D as L,ar as N}from"./registerWidgets.60bba559.js";import{p as l}from"./passwordlessManager.e1b568b1.js";import{a as C}from"./asyncComputed.d00a688c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="7c29c98c-f55d-408d-9e8f-3a9f839e149f",e._sentryDebugIdIdentifier="sentry-dbid-7c29c98c-f55d-408d-9e8f-3a9f839e149f")}catch{}})();const B={},v=e=>(u("data-v-439be421"),e=e(),p(),e),D={class:"logo"},S=v(()=>t("img",{class:"logo-img",src:k,alt:"Abstra cloud logo"},null,-1)),V=v(()=>t("span",null,"Abstra Cloud",-1)),U=[S,V];function A(e,c){return s(),o("div",D,U)}const E=i(B,[["render",A],["__scopeId","data-v-439be421"]]),F={key:0},R={key:1,class:"logged"},q={class:"author-email"},z={key:2},H=f({__name:"LoginBlock",setup(e){const c=I(),{result:a,loading:n,refetch:d}=C(async()=>l.getUser());function h(){l.removeUser(),d(),c.push({name:"login"})}return(P,W)=>{const y=x("router-link");return _(n)?(s(),o("div",F,"loading...")):_(a)?(s(),o("div",R,[t("span",q,b(_(a).claims.email),1),t("button",{class:"btn",onClick:h},"Logout")])):(s(),o("div",z,[r(y,{class:"btn",to:"/login"},{default:g(()=>[m("Login")]),_:1})]))}}});const M=i(H,[["__scopeId","data-v-6c08207b"]]),O=e=>(u("data-v-cf48b8cc"),e=e(),p(),e),Q={class:"nav"},T={class:"left"},j={key:0,class:"breadcrumb-container"},G=O(()=>t("span",{class:"divider"},">",-1)),J={class:"right"},K=f({__name:"Navbar",props:{breadcrumb:null},setup(e){return(c,a)=>(s(),o("nav",Q,[t("div",T,[r(E),e.breadcrumb?(s(),o("div",j,[(s(!0),o($,null,w(e.breadcrumb,(n,d)=>(s(),o("span",{key:d,class:"breadcrumb-item"},[r(_(N),{class:"breadcrumb-link",to:n.path},{default:g(()=>[m(b(n.label),1)]),_:2},1032,["to"]),G]))),128))])):L("",!0)]),t("div",J,[r(M)])]))}});const se=i(K,[["__scopeId","data-v-cf48b8cc"]]);export{se as N};
//# sourceMappingURL=Navbar.85a9a92e.js.map
