import{P as r}from"./Passwordless.4a584300.js";import{N as a}from"./Navbar.85a9a92e.js";import{d as c,b as i,c as d,e as t,H as p,q as _}from"./registerWidgets.60bba559.js";import{M as m}from"./member.4ea40a45.js";import"./CircularLoading.0edb8bc0.js";import"./lottie.fd5d7b21.js";import"./icons.86798a2e.js";import"./passwordlessManager.e1b568b1.js";import"./pubsub.6df2423b.js";import"./logo.084e5d7c.js";import"./asyncComputed.d00a688c.js";import"./gateway.aefff1da.js";import"./activeRecord.5794d4d2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="17e55254-62aa-4c98-bdc1-ced04cb096c9",e._sentryDebugIdIdentifier="sentry-dbid-17e55254-62aa-4c98-bdc1-ced04cb096c9")}catch{}})();const l={class:"login"},f=c({__name:"Login",setup(e){const o=p();async function s(n){await m.login(),o.push({name:"home"})}return(n,u)=>(i(),d("div",l,[t(a,{class:"nav"}),t(r,{class:"passwordless",onDone:s})]))}});const B=_(f,[["__scopeId","data-v-c9b2b4e6"]]);export{B as default};
//# sourceMappingURL=Login.3b573205.js.map
