import{P as d}from"./PlayerNavbar.d70763bf.js";import{d as m}from"./runnerData.178be36e.js";import{l as u,a as c,b as p}from"./colors.472988d2.js";import{d as k,K as n,b as i,c as b,x as f,z as o,t as y,D as g,A as w,q as _}from"./registerWidgets.60bba559.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="3ab00797-4563-4c82-8f10-3de56d49e98c",r._sentryDebugIdIdentifier="sentry-dbid-3ab00797-4563-4c82-8f10-3de56d49e98c")}catch{}})();function h(r){return r.startsWith("#")||r.match(/^(rgb|hsl)/)}function v(r){return r.startsWith("http://")||r.startsWith("https://")}function C(r){return v(r)?"external-image":h(r)?"color":"hosted-image"}function I(r,e="/_assets/background"){switch(C(r)){case"external-image":return{backgroundImage:`url(${r})`,backgroundSize:"cover",backgroundPosition:"center"};case"color":return{backgroundColor:r};case"hosted-image":return{backgroundImage:`url(${e})`,backgroundSize:"cover",backgroundPosition:"center"}}}const P={class:"sidebar-preview"},x=k({__name:"SidebarPreview",props:{workspace:null},setup(r){const e=r,a=n(()=>e.workspace.makeRunnerData()),l=n(()=>(document.documentElement.style.setProperty("--ac-global-font-family",e.workspace.fontFamily),{"--color-main":e.workspace.mainColor,"--color-main-light":u(e.workspace.mainColor,.15),"--color-main-hover":c(e.workspace.mainColor),"--color-main-active":c(e.workspace.mainColor),"--color-secondary":"transparent","--color-secondary-lighter":"transparent","--color-secondary-darker":"transparent","--button-font-color-main":p(e.workspace.mainColor),"--font-family":e.workspace.fontFamily,...I(e.workspace.theme,`/_editor/api/assets/${e.workspace.theme}`)})),s=n(()=>{var t;return e.workspace?{id:"mockId",path:"mockPath",title:"mockTitle",theme:e.workspace.theme,brandName:(t=e.workspace.brandName)!=null?t:null,logoUrl:"/_editor/api/assets/"+e.workspace.logoUrl,mainColor:e.workspace.mainColor,fontFamily:e.workspace.fontFamily,layout:m({props:{},slot:{},version:"0.2"}),workspaceName:"Untitled Workspace",sidebar:e.workspace.sidebar,runtimeType:"dash"}:null});return(t,D)=>(i(),b("div",P,[f("div",{class:"sidebar-frame",style:w(o(l))},[o(s)?(i(),y(d,{key:0,runtime:o(s),"brand-name":o(a).brandName,"user-email":"user@email.com","force-responsivity":"desktop"},null,8,["runtime","brand-name"])):g("",!0)],4)]))}});const z=_(x,[["__scopeId","data-v-d5d98bf1"]]);export{z as S,C as b};
//# sourceMappingURL=SidebarPreview.db9cd8bb.js.map
