import"./registerWidgets.60bba559.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="f719548f-ab5f-44f3-a807-a7e54aa31ac6",x._sentryDebugIdIdentifier="sentry-dbid-f719548f-ab5f-44f3-a807-a7e54aa31ac6")}catch{}})();const a=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{a as u};
//# sourceMappingURL=uuid.03790a84.js.map
