import{q as r,a,b as i,t as c,f as d,g as p,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.60bba559.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0ac1de70-4653-4c6f-83e5-bfdbd088616f",e._sentryDebugIdIdentifier="sentry-dbid-0ac1de70-4653-4c6f-83e5-bfdbd088616f")}catch{}})();const I={};function A(e,t){const n=a("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",A]]),o=d({history:p("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.caef6518.js"),["assets/Player.caef6518.js","assets/index.7e7f8bb2.js","assets/registerWidgets.60bba559.js","assets/registerWidgets.448db7e9.css","assets/uuid.03790a84.js","assets/broker.4c6f334d.js","assets/passwordlessManager.e1b568b1.js","assets/pubsub.6df2423b.js","assets/icons.86798a2e.js","assets/ActionButton.vue_vue_type_script_setup_true_lang.11413f0b.js","assets/Passwordless.4a584300.js","assets/CircularLoading.0edb8bc0.js","assets/lottie.fd5d7b21.js","assets/CircularLoading.f81b57b4.css","assets/Passwordless.86ac0c56.css","assets/executeJs.263d8eb0.js","assets/PlayerNavbar.d70763bf.js","assets/PlayerNavbar.76a7eb2f.css","assets/WidgetsFrame.c566de3c.js","assets/colors.472988d2.js","assets/WidgetsFrame.701a818b.css","assets/Modal.8fbea10f.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/broker.5f3abad8.css","assets/DashPlayer.f85774c5.js","assets/runnerData.178be36e.js","assets/DashPlayer.ef4a798d.css","assets/asyncComputed.d00a688c.js","assets/Player.20a058fa.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>f(x)});l.init(),D.init(),e.use(o),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,o),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.6fb02adc.js.map
