import{d as u,K as m,b as f,t as b,w as _,z as i,J as y,O as g,Q as w,x as n,U as d,q as h}from"./registerWidgets.60bba559.js";import{a as x}from"./asyncComputed.d00a688c.js";import"./gateway.aefff1da.js";import{B as I}from"./build.5d0701bc.js";import"./index.320037c9.js";import{C as v}from"./CrudView.a60cfd24.js";import{K as B,M as D}from"./icons.86798a2e.js";import{r as C}from"./console.8553c5f2.js";import{f as k}from"./index.b048d0fb.js";import"./passwordlessManager.e1b568b1.js";import"./pubsub.6df2423b.js";import"./activeRecord.5794d4d2.js";import"./DropdownMenu.5abb73fd.js";import"./Modal.8fbea10f.js";import"./LoadingIndicator.0b01cf4c.js";import"./lottie.fd5d7b21.js";import"./index.7e7f8bb2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="636937c6-e921-4004-a9fb-9b9585c3bab9",e._sentryDebugIdIdentifier="sentry-dbid-636937c6-e921-4004-a9fb-9b9585c3bab9")}catch{}})();const S=e=>(g("data-v-e61ab2b9"),e=e(),w(),e),V=S(()=>n("div",{class:"instructions"},[d(" Get started with the local editor in seconds: "),n("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),d(" And you're done! Explore the local editor and start building apps. ")],-1)),j=u({__name:"Builds",setup(e){const s=y().params.projectId,{loading:c,result:l}=x(()=>I.list(s)),p=m(()=>{var a,r;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(r=(a=l.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8),classes:["centered"]},{text:k(t.createdAt,Date.now(),{addSuffix:!0}),classes:[]},{text:t.status+(t.log?": "+t.log:""),classes:[]},{text:"",classes:["centered"],actions:[{icon:B,label:"View logs",onClick:()=>C.push({name:"logs",params:{projectId:s},query:{buildId:t.id}})},{icon:D,label:"Download files",onClick:()=>t.download()}]}]})))!=null?r:[]}});return(a,r)=>(f(),b(v,{"entity-name":"build",loading:i(c),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:i(p)},{"empty-description":_(()=>[V]),_:1},8,["loading","table"]))}});const H=h(j,[["__scopeId","data-v-e61ab2b9"]]);export{H as default};
//# sourceMappingURL=Builds.42caa057.js.map
