import{S as m}from"./Sidebar.0d64783f.js";import{N as d}from"./Navbar.85a9a92e.js";import{E as p,F as l,G as u}from"./icons.86798a2e.js";import{d as f,K as _,b,c as g,e as t,z as r,x as v,F as y,J as z,a as w,q as I}from"./registerWidgets.60bba559.js";import{a as h}from"./asyncComputed.d00a688c.js";import"./gateway.aefff1da.js";import{O}from"./organization.e7137f47.js";import"./index.320037c9.js";import"./Tooltip.c2c5e61a.js";import"./logo.084e5d7c.js";import"./passwordlessManager.e1b568b1.js";import"./pubsub.6df2423b.js";import"./activeRecord.5794d4d2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6688125f-ed36-48f2-8eff-e44862fce5aa",e._sentryDebugIdIdentifier="sentry-dbid-6688125f-ed36-48f2-8eff-e44862fce5aa")}catch{}})();const x={class:"organization"},k=f({__name:"Organization",setup(e){const n=z().params.organizationId,{result:o}=h(()=>O.get(n)),s=_(()=>o.value?[{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:p,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(B,D)=>{const c=w("router-view");return b(),g(y,null,[t(d,{breadcrumb:r(s)},null,8,["breadcrumb"]),v("div",x,[t(m,{class:"sidebar",sections:r(i)},null,8,["sections"]),t(c)])],64)}}});const R=I(k,[["__scopeId","data-v-7eef90b7"]]);export{R as default};
//# sourceMappingURL=Organization.df7280fe.js.map
