import{q as t,b as s,c as o}from"./registerWidgets.60bba559.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="a4b5ae1d-e13e-4225-9eb4-49c50869b736",e._sentryDebugIdIdentifier="sentry-dbid-a4b5ae1d-e13e-4225-9eb4-49c50869b736")}catch{}})();const r={},a={class:"organization-settings"};function i(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.80bba302.js.map
